.. _spkg_pdf2svg:

pdf2svg: PDF to SVG convertor
=============================

Description
-----------

pdf2svg is a tiny command-line utility using Cairo and Poppler to convert PDF
documents into SVG files. Multi-page PDF can be split up to one SVG per page by
passing a file naming specification.

License
-------

GPL

Upstream Contact
----------------

http://cityinthesky.co.uk/opensource/pdf2svg/


Type
----

optional


Dependencies
------------



Version Information
-------------------

See https://repology.org/project/pdf2svg/versions

Installation commands
---------------------

.. tab:: Sage distribution:

   This is a dummy package and cannot be installed using the Sage distribution.

.. tab:: Alpine:

   .. CODE-BLOCK:: bash

       $ apk add pdf2svg

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S pdf2svg

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install pdf2svg

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install pdf2svg

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install pdf2svg

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install graphics/pdf2svg

.. tab:: Homebrew:

   .. CODE-BLOCK:: bash

       $ brew install pdf2svg

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install pdf2svg

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-pdf2svg

.. tab:: Nixpkgs:

   .. CODE-BLOCK:: bash

       $ nix-env -f \'\<nixpkgs\>\' --install --attr pdf2svg

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install pdf2svg


If the system package is installed, ``./configure`` will check if it can be used.
